@@ -1,15 +1,9 @@
 from cleo import Application
 
 from config import __version__
-from config.cli import (
-    CloudFoundryCommand,
-    ConfigClientCommand,
-    DecryptCommand,
-    EncryptCommand,
-)
+from config.cli import ConfigClientCommand, DecryptCommand, EncryptCommand
 
 application = Application("config-client", f"{__version__}")
-application.add(CloudFoundryCommand())
 application.add(ConfigClientCommand())
 application.add(EncryptCommand())
 application.add(DecryptCommand())
