@@ -1,111 +1,86 @@
 """Module for retrieve application's config from Spring Cloud Config."""
+import asyncio
 import os
 from distutils.util import strtobool
-from functools import wraps
-from typing import Any, Callable, Dict, KeysView, Optional
+from functools import partial, wraps
+from typing import Any, Callable, Dict, KeysView, Optional, Tuple
 
-import attr
+from attrs import field, fields_dict, mutable, validators
 from glom import glom
 
 from . import http
+from ._config import merge_dict, to_dict
 from .auth import OAuth2
 from .core import singleton
 from .exceptions import RequestFailedException
 from .logger import logger
 
 
-@attr.s(slots=True)
+@mutable
 class ConfigClient:
     """Spring Cloud Config Client."""
 
-    address = attr.ib(
-        type=str,
+    address: str = field(
         default=os.getenv("CONFIGSERVER_ADDRESS", "http://localhost:8888"),
-        validator=attr.validators.instance_of(str),
+        validator=validators.instance_of(str),
     )
-    branch = attr.ib(
-        type=str,
-        default=os.getenv("BRANCH", "master"),
-        validator=attr.validators.instance_of(str),
+    label: str = field(
+        default=os.getenv("LABEL", "master"),
+        validator=validators.instance_of(str),
     )
-    app_name = attr.ib(
-        type=str,
+    app_name: str = field(
         default=os.getenv("APP_NAME", ""),
-        validator=attr.validators.instance_of(str),
+        validator=validators.instance_of(str),
     )
-    profile = attr.ib(
-        type=str,
+    profile: str = field(
         default=os.getenv("PROFILE", "development"),
-        validator=attr.validators.instance_of(str),
+        validator=validators.instance_of(str),
     )
-    _url = attr.ib(
-        type=str,
-        default="{address}/{branch}/{app_name}-{profile}.json",
-        validator=attr.validators.instance_of(str),
-        repr=False,
-    )
-    fail_fast = attr.ib(
-        type=bool,
+    fail_fast: bool = field(
         default=bool(strtobool(str(os.getenv("CONFIG_FAIL_FAST", True)))),
-        validator=attr.validators.instance_of(bool),
+        validator=validators.instance_of(bool),
         converter=bool,
     )
-    oauth2 = attr.ib(
-        type=Optional[OAuth2],
+    oauth2: Optional[OAuth2] = field(
         default=None,
-        validator=attr.validators.optional(attr.validators.instance_of(OAuth2)),
+        validator=validators.optional(validators.instance_of(OAuth2)),
     )
-    _config = attr.ib(
-        type=dict,
+    _config: dict = field(
         factory=dict,
         init=False,
-        validator=attr.validators.instance_of(dict),
+        validator=validators.instance_of(dict),
         repr=False,
     )
 
     @property
     def url(self) -> str:
-        url = self._url.format(
-            address=self.address,
-            branch=self.branch,
-            app_name=self.app_name,
-            profile=self.profile,
-        )
-        return self._ensure_request_json(url)
+        return f"{self.address}/{self.app_name}/{self.profile}/{self.label}"
 
-    @url.setter
-    def url(self, pattern: str) -> None:
-        self._url = pattern
-
-    def _ensure_request_json(self, url: str) -> str:
-        """Ensure that the URI to retrieve the configuration will have the .json extension"""
-        if not url.endswith(".json"):
-            dot_position = url.rfind(".")
-            if dot_position > 0:
-                url = url.replace(url[dot_position:], ".json")
-            else:
-                url = f"{url}.json"
-            logger.warning(
-                "URL suffix adjusted to a supported format. "
-                "For more details see: "
-                "https://config-client.amenezes.net/docs/1.-overview/#default-values"
-            )
-        logger.debug(f"Target URL: [address='{url}']")
-        return url
-
-    def get_config(self, **kwargs: dict) -> None:
+    def get_config(self, **kwargs) -> None:
         """Request the configuration from the config server."""
         kwargs = self._configure_oauth2(**kwargs)
         try:
             response = http.get(self.url, **kwargs)
-        except Exception as ex:
+        except Exception as err:
             logger.error(f"Failed to request: {self.url}")
-            logger.error(ex)
+            logger.error(err)
             if self.fail_fast:
                 logger.info("fail_fast enabled. Terminating process.")
                 raise SystemExit(1)
             raise ConnectionError("fail_fast disabled.")
-        self._config = response.json()
+        fconfig = [
+            to_dict(config)
+            for config in reversed(
+                glom(response.json(), ("propertySources", ["source"]))
+            )
+        ]
+        server_config: dict = {}
+        [merge_dict(server_config, c) for c in fconfig]
+        merge_dict(self._config, server_config)
+
+    async def get_config_async(self, **kwargs) -> None:
+        loop = asyncio.get_running_loop()
+        await loop.run_in_executor(None, partial(self.get_config, **kwargs))
 
     def _configure_oauth2(self, **kwargs) -> dict:
         if self.oauth2:
@@ -118,7 +93,7 @@ class ConfigClient:
 
     def get_file(self, filename: str, **kwargs: dict) -> str:
         """Request a file from the config server."""
-        uri = f"{self.address}/{self.app_name}/{self.profile}/{self.branch}/{filename}"
+        uri = f"{self.address}/{self.app_name}/{self.profile}/{self.label}/{filename}"
         try:
             response = http.get(uri, **kwargs)
         except Exception:
@@ -168,21 +143,6 @@ class ConfigClient:
     def keys(self) -> KeysView:
         return self._config.keys()
 
-    def get_attribute(self, value: str) -> Any:
-        """
-        Get attribute from configuration.
-
-        :value value: -- The filter to query on dict.
-        :return: The value matches or ''
-        """
-        logger.warning("get_attribute it's deprecated, please use get() method.")
-        return glom(self._config, value, default="")
-
-    def get_keys(self) -> KeysView:
-        """List all keys from configuration retrieved."""
-        logger.warning("get_keys it's deprecated, please use keys() method.")
-        return self._config.keys()
-
 
 @singleton
 def create_config_client(**kwargs) -> ConfigClient:
@@ -197,8 +157,9 @@ def create_config_client(**kwargs) -> ConfigClient:
     :param url:
     :return: ConfigClient instance.
     """
-    obj = ConfigClient(**kwargs)
-    obj.get_config()
+    instance_params, get_config_params = __get_params(**kwargs)
+    obj = ConfigClient(**instance_params)
+    obj.get_config(**get_config_params)
     return obj
 
 
@@ -214,19 +175,10 @@ def config_client(**kwargs) -> Callable[[Dict[str, str]], ConfigClient]:
     :raises: ConnectionError: If fail_fast enabled.
     :return: ConfigClient instance.
     """
-    logger.debug("kwargs: %r", kwargs)
-
-    cls_attributes = attr.fields_dict(ConfigClient).keys()
-    instance_params = {}
-    get_config_params = {}
-    for key, value in kwargs.items():
-        if key in cls_attributes:
-            instance_params.update({key: value})
-        else:
-            get_config_params.update({key: value})
+    instance_params, get_config_params = __get_params(**kwargs)
 
     def wrap_function(function):
-        logger.debug("caller: %s", function.__name__)
+        logger.debug(f"caller: [name='{function.__name__}']")
 
         @wraps(function)
         def enable_config():
@@ -237,3 +189,17 @@ def config_client(**kwargs) -> Callable[[Dict[str, str]], ConfigClient]:
         return enable_config
 
     return wrap_function
+
+
+def __get_params(**kwargs) -> Tuple[Dict, Dict]:
+    instance_params = {}
+    get_config_params = {}
+    for key, value in kwargs.items():
+        if key in fields_dict(ConfigClient).keys():
+            instance_params.update({key: value})
+        else:
+            get_config_params.update({key: value})
+    logger.debug(
+        f"params: [kwargs={kwargs}, instance={instance_params}, get_config={get_config_params}]"
+    )
+    return instance_params, get_config_params
